SystemOrganization addCategory: #ConfigurationOfDesigner!

Object subclass: #ConfigurationOfDesigner
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDesigner'!

!ConfigurationOfDesigner class methodsFor: 'development support' stamp: 'DaleHenrichs 12/17/2010 10:23'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfDesigner class methodsFor: 'private' stamp: 'DaleHenrichs 11/2/2010 16:51'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfDesigner class methodsFor: 'private' stamp: 'DaleHenrichs 12/6/2010 13:34'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfDesigner class methodsFor: 'private' stamp: 'DaleHenrichs 11/4/2010 10:23'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfDesigner class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 11/2/2010 14:58'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDesigner class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfDesigner class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfDesigner class methodsFor: 'loading' stamp: 'mt 5/2/2011 13:45:09.749'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfDesigner class methodsFor: 'accessing' stamp: 'dkh 10/13/2009 10:36'!
project

	^self new project! !

!ConfigurationOfDesigner class methodsFor: 'development support' stamp: 'DaleHenrichs 1/13/2011 15:37'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfDesigner methodsFor: 'baselines' stamp: 'mt 12/4/2010 10:44:00.687'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #('full')].
			
		spec package: 'Designer' with: [spec requires: #('Animations' 'Signals' 'Widgets')].
		spec group: 'default' with: #('Designer')].! !

!ConfigurationOfDesigner methodsFor: 'baselines' stamp: 'mt 5/1/2011 19:53:51.896'!
baseline110: spec 
	<version: '1.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #('full')].
			
		spec package: 'Designer' with: [spec
			requires: #('Animations' 'Signals' 'Widgets')].
		
		spec group: 'default' with: #('Designer')].! !

!ConfigurationOfDesigner methodsFor: 'symbolic versions' stamp: 'mt 2/5/2011 17:50:26.377'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.1'.
! !

!ConfigurationOfDesigner methodsFor: 'accessing' stamp: 'DaleHenrichs 11/5/2010 13:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfDesigner methodsFor: 'symbolic versions' stamp: 'mt 5/2/2012 14:39:57.243'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '1.1-snapshot-120502'.! !

!ConfigurationOfDesigner methodsFor: 'symbolic versions' stamp: 'mt 2/5/2011 17:47:09.43'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.1.x' version: '1.0'.
	spec for: #'squeak4.2.x' version: '1.0'.
! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 2/5/2011 17:41:55.874'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.1';
			project: 'Animations' with: '1.0';
			project: 'Widgets' with: '1.0'.
		
		spec package: 'Designer' with: 'Designer-mt.9'].! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 5/2/2011 13:44:31.394'!
version110: spec

	<version: '1.1' imports: #('1.1-baseline')>
		
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: #development;
			project: 'Animations' with: #development;
			project: 'Widgets' with: #development].! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 5/2/2011 13:48:19.241'!
version110snapshot110502: spec

	<version: '1.1-snapshot-110502' imports: #('1.1-baseline')>
		
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.3';
			project: 'Animations' with: '1.0.2';
			project: 'Widgets' with: '1.1-snapshot-110502'.
			
		spec package: 'Designer' with: 'Designer-mt.25'].! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 6/30/2011 14:01:20.636'!
version110snapshot110630: spec

	<version: '1.1-snapshot-110630' imports: #('1.1-baseline')>
		
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.4';
			project: 'Animations' with: '1.0.4';
			project: 'Widgets' with: '1.1-snapshot-110630'.
			
		spec package: 'Designer' with: 'Designer-mt.26'].! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 5/3/2012 09:47:56.04'!
version110snapshot120502: spec

	<version: '1.1-snapshot-120502' imports: #('1.1-baseline')>
		
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.5';
			project: 'Animations' with: '1.0.5';
			project: 'Widgets' with: '1.1-snapshot-120502'.
			
		spec package: 'Designer' with: 'Designer-mt.31'].! !
